@@ -2,9 +2,14 @@ from tkinter import *
 from tkinter import ttk
 from tkinter.messagebox import *
 from tkinter.simpledialog import *
+from colorama import Fore, Style
 
-from tkinterie.tkinterIE import WebView
-from src.Tki import *
+try:
+    from tkinterie.tkinterIE import WebView
+except ImportError:
+    print(Fore.RED + "Please Download tkinterie, install commnad: pip install tkinterie " + Style.RESET_ALL)
+from Tki.KiCore import *
+from Tki import *
 
 
 class KiWidget(KiObject, KiPack, KiPlace):
@@ -149,11 +154,24 @@ class KiScrollBar(KiWidget):
         self.Widget = Scrollbar(master=Master, background=Background, activebackground=ActiveBackground, relief=Relief,
                                 width=Width, orient=Orient)
 
-    def Configure(self, Master: KiWidget = None,
-                  Background: str = "white", ActiveForeground: str = "black", Relief: str = Relief_Flat,
-                  Width=0):
-        self.Widget.configure(master=Master, background=Background, activebackground=ActiveBackground, relief=Relief,
-                              width=Width)
+    def Configure(self, Background: str = Always, ActiveBackground: str = Always, Relief: str = Always,
+                  Width=Always):
+        if Background == Always:
+            self.Widget.configure(background=self.CGet("background"))
+        else:
+            self.Widget.configure(background=Background)
+        if ActiveBackground == Always:
+            self.Widget.configure(activebackground=self.CGet("activebackground"))
+        else:
+            self.Widget.configure(activebackground=ActiveBackground)
+        if Relief == Always:
+            self.Widget.configure(relief=self.CGet("relief"))
+        else:
+            self.Widget.configure(xscrollcommand=XScroll)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
 
     def SetValue(self, First, Last):
         self.Widget.set(first=First, last=Last)
@@ -165,20 +183,71 @@ class KiScrollBar(KiWidget):
 class KiTextView(KiWidget):
     def __init__(self, Master: KiWidget = None,
                  SelectBackground: str = "blue", SelectForeground: str = "white",
-                 Background: str = "white", Foreground: str = "black", XScroll: KiScrollBar = None, Relief: str = Relief_Flat,
+                 Background: str = "white", Foreground: str = "black", XScroll: KiScrollBar = None,
+                 Relief: str = Relief_Flat,
                  YScroll: KiScrollBar = None, Wrap: str = Wrap_Char, Font=None,
                  Width=0):
         super().__init__()
-        self.Widget = Text(master=Master, selectbackground=SelectBackground, selectforeground=SelectForeground, relief=Relief,
+        self.Widget = Text(master=Master, selectbackground=SelectBackground, selectforeground=SelectForeground,
+                           relief=Relief,
                            background=Background, foreground=Foreground, wrap=Wrap, font=Font,
                            xscrollcommand=XScroll, yscrollcommand=YScroll, width=Width)
+        self.Master = Master
+        self.SelectBackground = SelectBackground
+        self.SelectForeground = SelectForeground
+        self.Background = Background
+        self.Foreground = Foreground
+        self.XScroll = XScroll
+        self.YScroll = YScroll
+        self.Relief = Relief
+        self.Wrap = Wrap
+        self.Width = Width
 
-    def Configure(self, Master: KiWidget = None,
-                  SelectBackground: str = "white", SelectForeground: str = "black",
-                  Background: str = "white", Foreground: str = "black", XScroll: KiScrollBar = None, Relief: str = Relief_Flat,
-                  YScroll: KiScrollBar = None, Wrap: str = Wrap_Char, Font=None,
-                  Width=0):
-        self.Widget.configure(master=Master, selectbackground=SelectBackground, selectforeground=SelectForeground, relief=Relief,
+    def Configure(self, SelectBackground: str = Always, SelectForeground: str = Always,
+                  Background: str = Always, Foreground: str = Always, XScroll: KiScrollBar = Always,
+                  Relief: str = Always,
+                  YScroll: KiScrollBar = Always, Wrap: str = Always, Font=Always,
+                  Width=Always):
+        if SelectBackground == Always:
+            self.Widget.configure(selectbackground=self.CGet("selectbackground"))
+        else:
+            self.Widget.configure(selectbackground=SelectBackground)
+        if SelectForeground == Always:
+            self.Widget.configure(selectforeground=self.CGet("selectforeground"))
+        else:
+            self.Widget.configure(selectforeground=SelectForeground)
+        if Background == Always:
+            self.Widget.configure(background=self.CGet("background"))
+        else:
+            self.Widget.configure(background=Background)
+        if Foreground == Always:
+            self.Widget.configure(foreground=self.CGet("foreground"))
+        else:
+            self.Widget.configure(foreground=Foreground)
+        if XScroll == Always:
+            self.Widget.configure(xscrollcommand=self.CGet("xscrollcommnad"))
+        else:
+            self.Widget.configure(xscrollcommand=XScroll)
+
+        if YScroll == Always:
+            self.Widget.configure(yscrollcommand=self.CGet("yscrollcommand"))
+        else:
+            self.Widget.configure(yscrollcommand=YScroll)
+        if Relief == Always:
+            self.Widget.configure(relief=self.CGet("relief"))
+        else:
+            self.Widget.configure(relief=Relief)
+        if Wrap == Always:
+            self.Widget.configure(wrap=self.CGet("wrap"))
+        else:
+            self.Widget.configure(wrap=Wrap)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
+
+        self.Widget.configure(master=Master, selectbackground=SelectBackground, selectforeground=SelectForeground,
+                              relief=Relief,
                               background=Background, foreground=Foreground, wrap=Wrap, font=Font,
                               xscrollcommand=XScollBar, yscrollcommand=YScroll, width=Width)
 
@@ -191,11 +260,15 @@ class KiTextView(KiWidget):
     def WidgetCGet(self, Index):
         return self.Widget.window_cget(index=Index)
 
-    def TagConfig(self, TagName: str, Start: str, End: str = None, Background="white", Foreground="black", BorderWidth: int = 0, Justify: str = Jusitfy_Left, Font=None):
-        self.Widget.tag_config(tagName=TagName, index1=Start, index2=End, background=Background, foreground=Foreground, borderwidth=BorderWidth, justify=Justify, font=Font)
+    def TagConfig(self, TagName: str, Start: str, End: str = None, Background="white", Foreground="black",
+                  BorderWidth: int = 0, Justify: str = Jusitfy_Left, Font=None):
+        self.Widget.tag_config(tagName=TagName, index1=Start, index2=End, background=Background, foreground=Foreground,
+                               borderwidth=BorderWidth, justify=Justify, font=Font)
 
-    def TagAdd(self, TagName: str, Start: str, End: str = None, Background="white", Foreground="black", BorderWidth: int = 0, Justify: str = Jusitfy_Left, Font=None):
-        self.Widget.tag_add(tagName=TagName, index1=Start, index2=End, background=Background, foreground=Foreground, borderwidth=BorderWidth, justify=Justify, font=Font)
+    def TagAdd(self, TagName: str, Start: str, End: str = None, Background="white", Foreground="black",
+               BorderWidth: int = 0, Justify: str = Jusitfy_Left, Font=None):
+        self.Widget.tag_add(tagName=TagName, index1=Start, index2=End, background=Background, foreground=Foreground,
+                            borderwidth=BorderWidth, justify=Justify, font=Font)
 
     def TagRemove(self, TagName: str, Start: str, End: str = None):
         self.Widget.tag_remove(tagName=TagName, index1=Start, index2=End)
@@ -270,13 +343,42 @@ class KiButton(KiWidget):
     def SetCommand(self, Func):
         self.Configure(Command=Func)
 
-    def Configure(self, Master: KiWidget = None, Text: str = EmptyString, Command=EmptyFunc,
-                  ActiveBackground: str = "white", ActiveForeground: str = "black",
-                  Background: str = "white", Foreground: str = "black", Justify: str = Jusitfy_Center,
-                  Width=0):
-        self.Widget.configure(master=Master, text=Text, command=Command,
-                              activebackground=ActiveBackground, activeforeground=ActiveForeground,
-                              background=Background, foreground=Foreground, justify=Justify, width=Width)
+    def Configure(self, Text: str = Always, Command=Always,
+                  ActiveBackground: str = Always, ActiveForeground: str = Always,
+                  Background: str = Always, Foreground: str = Always, Justify: str = Always,
+                  Width=Always):
+        if ActiveBackground == Always:
+            self.Widget.configure(activebackground=self.CGet("activebackground"))
+        else:
+            self.Widget.configure(activebackground=ActiveBackground)
+        if ActiveForeground == Always:
+            self.Widget.configure(activeforeground=self.CGet("activeforeground"))
+        else:
+            self.Widget.configure(activeforeground=ActiveForeground)
+        if Background == Always:
+            self.Widget.configure(background=self.CGet("background"))
+        else:
+            self.Widget.configure(background=Background)
+        if Foreground == Always:
+            self.Widget.configure(foreground=self.CGet("foreground"))
+        else:
+            self.Widget.configure(foreground=Foreground)
+        if Text == Always:
+            self.Widget.configure(text=self.CGet("text"))
+        else:
+            self.Widget.configure(text=Text)
+        if Command == Always:
+            self.Widget.configure(command=self.CGet("command"))
+        else:
+            self.Widget.configure(command=Command)
+        if Justify == Always:
+            self.Widget.configure(justify=self.CGet("justify"))
+        else:
+            self.Widget.configure(justify=Justify)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
 
     def Flash(self):
         self.Widget.flash()
@@ -288,10 +390,39 @@ class KiEntry(KiWidget):
                  Justify: str = Jusitfy_Left, Width=0):
         super().__init__()
         self.Text = KiStringVar()
-        self.Widget = Entry(master=Master, textvariable=self.Text.Get(), background=Background, foreground=Foreground, font=Font,
+        self.Widget = Entry(master=Master, textvariable=self.Text.Get(), background=Background, foreground=Foreground,
+                            font=Font,
                             justify=Justify, width=Width)
         self.SetText(Text)
 
+    def Configure(self, Text: str = Always,
+                  Background: str = Always, Foreground: str = Always, Font=Always,
+                  Justify: str = Always, Width=Always):
+        if Text == Always:
+            self.SetText(self.CGet("textvariable").set(Text))
+        else:
+            self.SetText(Text)
+        if Background == Always:
+            self.Widget.configure(background=self.CGet("background"))
+        else:
+            self.Widget.configure(background=Background)
+        if Foreground == Always:
+            self.Widget.configure(foreground=self.CGet("foreground"))
+        else:
+            self.Widget.configure(foreground=Foreground)
+        if Font == Always:
+            self.Widget.configure(font=self.CGet("font"))
+        else:
+            self.Widget.configure(font=Font)
+        if Justify == Always:
+            self.Widget.configure(justify=self.CGet("justify"))
+        else:
+            self.Widget.configure(justify=Justify)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
+
     def SetText(self, Text):
         self.Text.SetVar(Text)
 
@@ -301,18 +432,35 @@ class KiEntry(KiWidget):
 
 class KiFrame(KiWidget):
     def __init__(self, Master: KiWidget = None, Background: str = "white",
-                 Padx=0, Pady=0, iPadx=0, iPady=0, Relief: str = Relief_Sunken,
+                 Padx=0, Pady=0, Relief: str = Relief_Sunken,
                  Width=0):
         super().__init__()
         self.Widget = Frame(master=Master, background=Background, width=Width,
                             padx=Padx, pady=Pady)
 
-    def Configure(self, Master: KiWidget = None, Background: str = "white",
-                  Padx=0, Pady=0, iPadx=0, iPady=0, Relief: str = Relief_Sunken,
-                  Width=0):
-        self.Widget.configure(master=Master,
-                              background=Background, relief=Relief,
-                              width=Width, padx=Padx, pady=Pady, ipadx=iPadx, ipady=iPady)
+    def Configure(self, Background: str = Always,
+                  Padx=Always, Pady=Always, iPadx=Always, iPady=Always, Relief: str = Always,
+                  Width=Always):
+        if Background == Always:
+            self.Widget.configure(background=self.CGet("background"))
+        else:
+            self.Widget.configure(background=Background)
+        if Padx == Always:
+            self.Widget.configure(padx=self.CGet("padx"))
+        else:
+            self.Widget.configure(padx=Padx)
+        if Pady == Always:
+            self.Widget.configure(pady=self.CGet("pady"))
+        else:
+            self.Widget.configure(pady=Pady)
+        if Relief == Always:
+            self.Widget.configure(relief=self.CGet("relief"))
+        else:
+            self.Widget.configure(relief=Relief)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
 
 
 class KiMessage(KiWidget):
@@ -321,10 +469,11 @@ class KiMessage(KiWidget):
                  Background: str = "white", Foreground: str = "black", Justify: str = Jusitfy_Center, Font=None,
                  Width=0):
         super().__init__()
-        self.Widget = Message(master=Master, text=Text, background=Background, foreground=Foreground, justify=Justify, font=Font,
+        self.Widget = Message(master=Master, text=Text, background=Background, foreground=Foreground, justify=Justify,
+                              font=Font,
                               width=Width)
 
-    def Configure(self, Master: KiWidget = None, Text: str = EmptyString, Command=EmptyFunc,
+    def Configure(self, Master: KiWidget = None, Text: str = EmptyString,
                   ActiveBackground: str = "white", ActiveForeground: str = "black",
                   Background: str = "white", Foreground: str = "black", Justify: str = Jusitfy_Center,
                   Width=0):
@@ -352,6 +501,28 @@ class KiTEntry(KiWidget):
         self.Widget = ttk.Entry(master=Master, textvariable=self.Text.Get(), justify=Justify, width=Width, font=Font)
         self.SetText(Text)
 
+    def Configure(self, Text: str = Always, Font=Always, Style: str = Always, Width=Always, Justify: str = Always):
+        if Text == Always:
+            self.SetText(self.CGet("textvariable").set(Text))
+        else:
+            self.SetText(Text)
+        if Font == Always:
+            self.Widget.configure(font=self.CGet("font"))
+        else:
+            self.Widget.configure(font=Font)
+        if Style == Always:
+            self.Widget.configure(style=self.CGet("style"))
+        else:
+            self.Widget.configure(style=Style)
+        if Justify == Always:
+            self.Widget.configure(justify=self.CGet("justify"))
+        else:
+            self.Widget.configure(justify=Justify)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
+
     def SetText(self, Text):
         self.Text.SetVar(Text)
 
@@ -366,11 +537,23 @@ class KiTButton(KiWidget):
         self.Widget = ttk.Button(master=Master, text=Text, command=Command,
                                  width=Width, style=Style)
 
-    def Configure(self, Master: KiWidget = None, Text: str = EmptyString, Command=EmptyFunc, Style: str = None,
-                  Justify: str = Jusitfy_Center,
-                  Width=0):
-        self.Widget.configure(master=Master, text=Text, command=Command,
-                              width=Width, style=Style)
+    def Configure(self, Text: str = Always, Command=Always, Style: str = Always,Width=Always):
+        if Text == Always:
+            self.Widget.configure(text=self.CGet("text"))
+        else:
+            self.Widget.configure(text=Text)
+        if Command == Always:
+            self.Widget.configure(command=self.CGet("command"))
+        else:
+            self.Widget.configure(command=Command)
+        if Style == Always:
+            self.Widget.configure(style=self.CGet("style"))
+        else:
+            self.Widget.configure(style=Style)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
 
     def SetAccent(self):
         self.Configure(Style="Accent.TButton")
@@ -386,12 +569,23 @@ class KiTButton(KiWidget):
 
 
 class KiTFrame(KiWidget):
-    def __init__(self, Master: KiWidget = None, Relief: str = Relief_Sunken, Width=0):
+    def __init__(self, Master: KiWidget = None, Relief: str = Relief_Sunken, Width=0, Style: str = None):
         super().__init__()
-        self.Widget = ttk.Frame(master=Master, relief=Relief, width=Width)
+        self.Widget = ttk.Frame(master=Master, relief=Relief, width=Width, style=Style)
 
-    def Configure(self, Relief: str = Relief_Sunken, Width=0):
-        self.Widget.configure(relief=Relief, width=Width)
+    def Configure(self, Relief: str = Relief_Sunken, Style: str = None, Width=0):
+        if Relief == Always:
+            self.Widget.configure(relief=self.CGet("relief"))
+        else:
+            self.Widget.configure(relief=Relief)
+        if Style == Always:
+            self.Widget.configure(style=self.CGet("style"))
+        else:
+            self.Widget.configure(style=Style)
+        if Width == Always:
+            self.Widget.configure(width=self.CGet("width"))
+        else:
+            self.Widget.configure(width=Width)
 
 
 class KiSideBar(KiFrame):
@@ -410,7 +604,7 @@ class KiSideBar(KiFrame):
         self.Widget.PackWidget(Side=Side, Fill=Fill_Y, Padx=Padx, Pady=Pady, iPadx=iPadx, iPady=iPady)
 
 
-class KiWebViewIE(KiWidget):
+class KiWebViewIE(KiFrame):
     def __init__(self, Master: KiWidget, Width, Height, Url):
         super().__init__()
         self.Widget = WebView(Master.GetWidget(), Width, Height, Url)
@@ -421,28 +615,36 @@ class KiMessgaeBox(KiWindow):
         super().__init__()
         self.Widget = Message()
 
-    def ShowInfo(self, Title: str = "Info", Message: str = "This is a info dialog", Icon: str = Message_Icons_INFO, Parent=None):
+    def ShowInfo(self, Title: str = "Info", Message: str = "This is a info dialog", Icon: str = Message_Icons_INFO,
+                 Parent=None):
         return showinfo(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def ShowError(self, Title: str = "Error", Message: str = "This is a error dialog", Icon: str = Message_Icons_ERROR, Parent=None):
+    def ShowError(self, Title: str = "Error", Message: str = "This is a error dialog", Icon: str = Message_Icons_ERROR,
+                  Parent=None):
         return showerror(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def ShowWarning(self, Title: str = "Warning", Message: str = "This is a warning dialog", Icon: str = Message_Icons_WARNING, Parent=None):
+    def ShowWarning(self, Title: str = "Warning", Message: str = "This is a warning dialog",
+                    Icon: str = Message_Icons_WARNING, Parent=None):
         return showwarning(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def AskYesNo(self, Title: str = "Ask", Message: str = "This is a yesno dialog", Icon: str = Message_Icons_QUESTION, Parent=None):
+    def AskYesNo(self, Title: str = "Ask", Message: str = "This is a yesno dialog", Icon: str = Message_Icons_QUESTION,
+                 Parent=None):
         return askyesno(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def AskOkCanel(self, Title: str = "Warning", Message: str = "This is a okcanel dialog", Icon: str = Message_Icons_QUESTION, Parent=None):
+    def AskOkCanel(self, Title: str = "Warning", Message: str = "This is a okcanel dialog",
+                   Icon: str = Message_Icons_QUESTION, Parent=None):
         return askokcancel(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def AskQuestion(self, Title: str = "Warning", Message: str = "This is a question dialog", Icon: str = Message_Icons_QUESTION, Parent=None):
+    def AskQuestion(self, Title: str = "Warning", Message: str = "This is a question dialog",
+                    Icon: str = Message_Icons_QUESTION, Parent=None):
         return askquestion(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def AskRetryCanel(self, Title: str = "Warning", Message: str = "This is a retrycanel dialog", Icon: str = Message_Icons_QUESTION, Parent=None):
+    def AskRetryCanel(self, Title: str = "Warning", Message: str = "This is a retrycanel dialog",
+                      Icon: str = Message_Icons_QUESTION, Parent=None):
         return askretrycancel(title=Title, message=Message, icon=Icon, parent=Parent)
 
-    def AskYesNoCanel(self, Title: str = "Warning", Message: str = "This is a yesnocanel dialog", Icon: str = Message_Icons_QUESTION, Parent=None):
+    def AskYesNoCanel(self, Title: str = "Warning", Message: str = "This is a yesnocanel dialog",
+                      Icon: str = Message_Icons_QUESTION, Parent=None):
         return askyesnocancel(title=Title, message=Message, icon=Icon, parent=Parent)
 
 
@@ -454,4 +656,4 @@ class KiMessgaeSimple(KiWindow):
         return askinteger()
 
     def AskString(self, Title: str = "ask string", Prompt: str = "plase entry string"):
-        return askstring()
\ No newline at end of file
+        return askstring()
